@@ -239,7 +239,7 @@ sub get_suite
 	my %suitemap=();
 	my ($cur_pri, $max_pri, $max_pri_suite, $suite, $tmp_suite);
 	# list of suites supported by Emdebian toolchain repository.
-	my @suites = qw/unstable testing stable sid lenny etch squeeze/;
+	my @suites = qw/unstable testing oldstable stable sid lenny etch squeeze/;
 	# Improved to detect priority. Ben Hutchings <ben@decadent.org.uk>
 	open POLICY, "apt-cache policy |" or carp "Unable to read apt policy: $!";
 	return "unstable" unless <POLICY>;
