@@ -553,7 +553,8 @@ END
 			next if $source =~ /^#/;
 			next if $source =~ /^$/;
 			next if ((defined $suite) and ($source !~ /$suite/));
-			print SOURCES $source;
+			chomp ($source);
+			print SOURCES "$source\n";
 		}
 		close SOURCES;
 		# if an emdebian source has not been specified, the lack of this file produces an annoying warning.
@@ -632,10 +633,17 @@ provide sources for your cross caches.
 
 sub prepare_sources_list
 {
+	my %hash=();
 	# collate all available/configured sources into one list
 	if (-e "/etc/apt/sources.list") {
 		open (SOURCES, "/etc/apt/sources.list") or die "cannot open apt sources list. $!";
-		@source_list = <SOURCES>;
+		while(<SOURCES>) {
+			next if /^#/;
+			next if /^$/;
+			my $src = $_;
+			chomp ($src);
+			$hash{$src}++;
+		}
 		close (SOURCES);
 	}
 	if (-d "/etc/apt/sources.list.d/") {
@@ -647,12 +655,17 @@ sub prepare_sources_list
 			open (SOURCES, "/etc/apt/sources.list.d/$f") or
 				die "cannot open /etc/apt/sources.list.d/$f $!";
 			while(<SOURCES>) {
-				push @source_list, $_;
+				next if /^#/;
+				next if /^$/;
+				my $src = $_;
+				chomp ($src);
+				$hash{$src}++;
 			}
 			close (SOURCES);
 		}
 		closedir (FILES);
 	}
+	@source_list = sort keys (%hash);
 	return \@source_list;
 }
 
